# Generated by Django 3.1.3 on 2020-11-23 14:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('sso_auth', '0003_oauthuser_groups'),
    ]

    operations = [
        migrations.AddField(
            model_name='oauthuser',
            name='user_permissions',
            field=models.ManyToManyField(blank=True, related_name='user_set', related_query_name='user', to='auth.Permission', verbose_name='user permissions'),
        ),
    ]
