# Generated by Django 3.1.3 on 2020-11-23 11:11

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sso_auth', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='oauthuser',
            name='groups',
        ),
        migrations.RemoveField(
            model_name='oauthuser',
            name='user_permissions',
        ),
    ]
